@@ -57,33 +57,33 @@ class ModelResults:
         vocab = vectorizer.get_feature_names()
         vector_df = pd.DataFrame(vectors, columns=vocab, index=X.index)
 
-        proportions_list = []
-
-        texts = X[text_column_name].apply(lambda x: ct.lematize(x))
-
-        # In gensim a dictionary is a mapping between words and their integer id
-        dictionary = Dictionary(texts)
-
-        # Filter out extremes to limit the number of features
-        dictionary.filter_extremes(no_below=2, no_above=0.85, keep_n=5000)
-
-        # Create the bag-of-words format (list of (token_id, token_count))
-        corpus = [dictionary.doc2bow(text) for text in texts]
-
-        if X.shape[0] < 20:
-            return "Too few examples to categorize."
-
-        # In case 1, add 1 to get at least 2
-        # The rest are based on eyeballing numbers
-        min_topics = ceil(X.shape[0] * 0.01) + 1
-        max_topics = ceil(X.shape[0] * 0.4)
-        step = ceil((max_topics - min_topics) / 5)
-
-        topic_nums = list(np.arange(min_topics, max_topics, step))
-
-        coherence_scores = []
-
         if not num_topics:
+            if X.shape[0] < 20:
+                return "Too few examples to categorize."
+
+            # In case 1, add 1 to get at least 2
+            # The rest are based on eyeballing numbers
+            min_topics = ceil(X.shape[0] * 0.01) + 1
+            max_topics = ceil(X.shape[0] * 0.4)
+            step = ceil((max_topics - min_topics) / 5)
+
+            topic_nums = list(np.arange(min_topics, max_topics, step))
+
+            proportions_list = []
+
+            texts = X[text_column_name].apply(lambda x: ct.lematize(x))
+
+            # In gensim a dictionary is a mapping between words and their integer id
+            dictionary = Dictionary(texts)
+
+            # Filter out extremes to limit the number of features
+            dictionary.filter_extremes(no_below=2, no_above=0.85, keep_n=5000)
+
+            # Create the bag-of-words format (list of (token_id, token_count))
+            corpus = [dictionary.doc2bow(text) for text in texts]
+
+            coherence_scores = []
+
             for num in topic_nums:
                 model = nmf.Nmf(
                     corpus=corpus,
@@ -151,17 +151,43 @@ class ModelResults:
             )
 
         topic_words_df = pd.DataFrame(
-            columns=["topic_num", "top_words_and_phrases", "sample_texts"]
+            columns=[
+                "topic_num",
+                "num_in_category",
+                "top_words_and_phrases",
+                "sample_texts",
+            ]
         )
 
         topic_words_df["topic_num"] = [x for x in topic_words.keys()]
+        topic_words_df["num_in_category"] = (
+            combined_df.groupby("top_topic_num").count().iloc[:, 0]
+        )
         topic_words_df["top_words_and_phrases"] = [x for x in topic_words.values()]
         topic_words_df["sample_texts"] = sample_texts_lst
 
-        print("Topics created with top words & example texts:")
-        print(topic_words_df)
+        topic_words_explode = pd.DataFrame(
+            topic_words_df["sample_texts"].tolist(), index=topic_words_df.index,
+        )
 
-        return topic_words_df, combined_df[[text_column_name, "top_topic_num"]]
+        topic_words_explode.columns = [
+            "example{}".format(num) for num in range(len(topic_words_explode.columns))
+        ]
+
+        concated_topics = pd.concat(
+            [
+                topic_words_df[
+                    ["topic_num", "num_in_category", "top_words_and_phrases"]
+                ],
+                topic_words_explode,
+            ],
+            axis=1,
+        )
+
+        print("Topics created with top words & example texts:")
+        print(concated_topics)
+
+        return concated_topics, combined_df[[text_column_name, "top_topic_num"]]
 
     def coefficients_summary(
         self, X, y, num_repetitions, num_coefficients, model_type, params={}
